@@ -6,6 +6,6 @@ BETTER_500_LOG_DIR = getattr(settings, "BETTER_500_LOG_DIR", join(dirname(manage
 BETTER_500_FROM_EMAIL = getattr(settings, "BETTER_500_FROM_EMAIL", getattr(settings, "DEFAULT_FROM_EMAIL", None))
 BETTER_500_TO_EMAILS = getattr(settings, "BETTER_500_TO_EMAILS", getattr(settings, "ADMINS", None))
 BETTER_500_UNCAUGHT_DIR = getattr(settings, "BETTER_500_UNCAUGHT_DIR", "UNCAUGHT")
-BETTER_500_AJAX_URL = getattr(settings, "BETTER_500_AJAX_URL", "better-500-callback/")
-BETTER_500_POST_URL = getattr(settings, "BETTER_500_POST_URL", "better-500-saved/")
-BETTER_500_DEFAULT_RETURN_URL_NAME = getattr(settings, "BETTER_500_DEFAULT_RETURN_URL_NAME", "home")
\ No newline at end of file
+BETTER_500_AJAX_URL = getattr(settings, "BETTER_500_AJAX_URL", "better_500_response")
+BETTER_500_POST_URL = getattr(settings, "BETTER_500_POST_URL", "better_500_saved")
+BETTER_500_DEFAULT_RETURN_URL_NAME = getattr(settings, "BETTER_500_DEFAULT_RETURN_URL_NAME", "home")
